summaryrefslogtreecommitdiff
path: root/fpdf_test.go
diff options
context:
space:
mode:
Diffstat (limited to 'fpdf_test.go')
-rw-r--r--fpdf_test.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/fpdf_test.go b/fpdf_test.go
index 30ee11b..0bcd2f6 100644
--- a/fpdf_test.go
+++ b/fpdf_test.go
@@ -2273,10 +2273,10 @@ func ExampleFpdf_RegisterAlias() {
// Successfully generated pdf/Fpdf_RegisterAlias.pdf
}
// ExampleFpdf_RegisterAliasUTF8 demonstrates how to use `RegisterAlias` to
// create a table of contents. This particular example demonstrates the use of
// UTF-8 aliases.
-func ExampleFpdf_RegisterAliasUTF8() {
+func ExampleFpdf_RegisterAlias_utf8() {
pdf := gofpdf.New("P", "mm", "A4", "")
pdf.AddUTF8Font("dejavu", "", example.FontFile("DejaVuSansCondensed.ttf"))
pdf.SetFont("dejavu", "", 12)
@@ -2273,10 +2273,10 @@ func ExampleFpdf_RegisterAlias() {
// Successfully generated pdf/Fpdf_RegisterAlias.pdf
}
-// ExampleFpdf_RegisterAliasUTF8 demonstrates how to use `RegisterAlias` to
+// ExampleFpdf_RegisterAlias_utf8 demonstrates how to use `RegisterAlias` to
// create a table of contents. This particular example demonstrates the use of
// UTF-8 aliases.